==> beast-trans-api-2.3.7-20250311.092128-9-sources.jar: com/thebeastshop/trans/vo/order/ai/TsOrderAiPackageVO.java <==
package com.thebeastshop.trans.vo.order.ai;

import com.thebeastshop.common.BaseDO;

import java.util.List;

/**
 * @author xiang.gao
 * @date 2025/3/10 19:17
 */
public class TsOrderAiPackageVO extends BaseDO {

    /**
     * 包裹序号
     */
    private String code;

    /**
     * 包裹状态
     */
    private String status;

    /**
     * 配送信息
     */
    private List<String> deliveryInfo;

    /**
     * 预计发货日期
     */
    private String planedDeliveryDate;

    /**
     * 期望送达日期
     */
    private String expectedSendDate;

    /**
     * 是否转门店
     */
    private boolean forwardStore;

    /**
     * 是否有留言卡
     */
    private boolean hasMessageCard;

    /**
     * 收货人
     */
    private String receiver;

    /**
     * 收货电话
     */
    private String receiverPhone;

    /**
     * 收货城市
     */
    private String receiverCity;

    /**
     * 收获地址
     */
    private String receiverAddress;

    /**
     * 商品信息
     */
    private List<TsOrderAiProductVO> packageProducts;

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }

    public String getStatus() {
        return status;
    }

    public void setStatus(String status) {
        this.status = status;
    }

    public List<String> getDeliveryInfo() {
        return deliveryInfo;
    }

    public void setDeliveryInfo(List<String> deliveryInfo) {
        this.deliveryInfo = deliveryInfo;
    }

    public String getPlanedDeliveryDate() {
        return planedDeliveryDate;
    }

    public void setPlanedDeliveryDate(String planedDeliveryDate) {
        this.planedDeliveryDate = planedDeliveryDate;
    }

    public String getExpectedSendDate() {
        return expectedSendDate;
    }

    public void setExpectedSendDate(String expectedSendDate) {
        this.expectedSendDate = expectedSendDate;
    }

    public boolean isForwardStore() {
        return forwardStore;
    }

    public void setForwardStore(boolean forwardStore) {
        this.forwardStore = forwardStore;
    }

    public boolean isHasMessageCard() {
        return hasMessageCard;
    }

    public void setHasMessageCard(boolean hasMessageCard) {
        this.hasMessageCard = hasMessageCard;
    }

    public String getReceiver() {
        return receiver;
    }

    public void setReceiver(String receiver) {
        this.receiver = receiver;
    }

    public String getReceiverPhone() {
        return receiverPhone;
    }

    public void setReceiverPhone(String receiverPhone) {
        this.receiverPhone = receiverPhone;
    }

    public String getReceiverCity() {
        return receiverCity;
    }

    public void setReceiverCity(String receiverCity) {
        this.receiverCity = receiverCity;
    }

    public String getReceiverAddress() {
        return receiverAddress;
    }

    public void setReceiverAddress(String receiverAddress) {
        this.receiverAddress = receiverAddress;
    }

    public List<TsOrderAiProductVO> getPackageProducts() {
        return packageProducts;
    }

    public void setPackageProducts(List<TsOrderAiProductVO> packageProducts) {
        this.packageProducts = packageProducts;
    }

}

==> beast-trans-api-2.3.7-20250311.100920-16-sources.jar: com/thebeastshop/trans/vo/order/ai/TsOrderAiPackageVO.java <==
package com.thebeastshop.trans.vo.order.ai;

import com.thebeastshop.common.BaseDO;

import java.util.List;

/**
 * @author xiang.gao
 * @date 2025/3/10 19:17
 */
public class TsOrderAiPackageVO extends BaseDO {

    /**
     * 包裹序号
     */
    private String packageCode;

    /**
     * 包裹状态
     */
    private String status;

    /**
     * 配送信息
     */
    private List<String> deliveryInfo;

    /**
     * 预计发货日期
     */
    private String planedDeliveryDate;

    /**
     * 期望送达日期
     */
    private String expectedSendDate;

    /**
     * 是否转门店
     */
    private boolean forwardStore;

    /**
     * 是否有留言卡
     */
    private boolean hasMessageCard;

    /**
     * 收货人
     */
    private String receiver;

    /**
     * 收货电话
     */
    private String receiverPhone;

    /**
     * 收货城市
     */
    private String receiverCity;

    /**
     * 收获地址
     */
    private String receiverAddress;

    /**
     * 商品信息
     */
    private List<TsOrderAiProductVO> packageProducts;

    public String getPackageCode() {
        return packageCode;
    }

    public void setPackageCode(String packageCode) {
        this.packageCode = packageCode;
    }

    public String getStatus() {
        return status;
    }

    public void setStatus(String status) {
        this.status = status;
    }

    public List<String> getDeliveryInfo() {
        return deliveryInfo;
    }

    public void setDeliveryInfo(List<String> deliveryInfo) {
        this.deliveryInfo = deliveryInfo;
    }

    public String getPlanedDeliveryDate() {
        return planedDeliveryDate;
    }

    public void setPlanedDeliveryDate(String planedDeliveryDate) {
        this.planedDeliveryDate = planedDeliveryDate;
    }

    public String getExpectedSendDate() {
        return expectedSendDate;
    }

    public void setExpectedSendDate(String expectedSendDate) {
        this.expectedSendDate = expectedSendDate;
    }

    public boolean isForwardStore() {
        return forwardStore;
    }

    public void setForwardStore(boolean forwardStore) {
        this.forwardStore = forwardStore;
    }

    public boolean isHasMessageCard() {
        return hasMessageCard;
    }

    public void setHasMessageCard(boolean hasMessageCard) {
        this.hasMessageCard = hasMessageCard;
    }

    public String getReceiver() {
        return receiver;
    }

    public void setReceiver(String receiver) {
        this.receiver = receiver;
    }

    public String getReceiverPhone() {
        return receiverPhone;
    }

    public void setReceiverPhone(String receiverPhone) {
        this.receiverPhone = receiverPhone;
    }

    public String getReceiverCity() {
        return receiverCity;
    }

    public void setReceiverCity(String receiverCity) {
        this.receiverCity = receiverCity;
    }

    public String getReceiverAddress() {
        return receiverAddress;
    }

    public void setReceiverAddress(String receiverAddress) {
        this.receiverAddress = receiverAddress;
    }

    public List<TsOrderAiProductVO> getPackageProducts() {
        return packageProducts;
    }

    public void setPackageProducts(List<TsOrderAiProductVO> packageProducts) {
        this.packageProducts = packageProducts;
    }

}
